@@ -25,7 +25,22 @@ class CameraCtrlsWindow(Gtk.ApplicationWindow):
         self.refresh_devices()
 
     def init_window(self):
-        self.set_default_icon_from_file(f'{sys.path[0]}/images/icon_256.png')
+        css_provider = Gtk.CssProvider()
+        css_provider.load_from_data(b'''
+        #white-balance-temperature trough {
+            background-image: linear-gradient(to right, 
+                #89F3FF, #AFF7FF, #DDFCFF, #FFF2AA, #FFDD27, #FFC500, #FFB000, #FF8D00, #FF7A00
+            );
+        }
+        #white-balance-temperature trough:disabled {
+            background-blend-mode: color;
+        }
+        ''')
+
+        Gtk.StyleContext.add_provider_for_screen(
+            Gdk.Screen.get_default(), css_provider,
+            Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
+        )
 
         hambuger_menu = Gtk.Box(
             orientation=Gtk.Orientation.VERTICAL,
@@ -213,7 +228,7 @@ class CameraCtrlsWindow(Gtk.ApplicationWindow):
                         adjustment = Gtk.Adjustment(lower=c.min, upper=c.max, value=c.value, step_increment=1)
                         adjustment.connect('value-changed', lambda a,c=c: self.update_ctrl(c, a.get_value()))
                         scale = Gtk.Scale(orientation=Gtk.Orientation.HORIZONTAL,
-                            digits=0, value_pos=Gtk.PositionType.LEFT, adjustment=adjustment, width_request=264)
+                            digits=0, has_origin=False, value_pos=Gtk.PositionType.LEFT, adjustment=adjustment, width_request=264)
                         if c.zeroer:
                             scale.connect('button-release-event', lambda sc, e: sc.set_value(0))
                             scale.connect('key-release-event', lambda sc, e: sc.set_value(0))
@@ -221,6 +236,8 @@ class CameraCtrlsWindow(Gtk.ApplicationWindow):
                             adjustment_step = Gtk.Adjustment(lower=c.min, upper=c.max, value=c.value, step_increment=c.step)
                             adjustment_step.connect('value-changed', lambda a,c=c,a1=adjustment: [a.set_value(a.get_value() - a.get_value() % c.step),a1.set_value(a.get_value())])
                             scale.set_adjustment(adjustment_step)
+                        if c.wbtemperature:
+                            scale.set_name('white-balance-temperature')
 
                         if c.default != None:
                             scale.add_mark(value=c.default, position=Gtk.PositionType.BOTTOM, markup=None)
@@ -363,8 +380,9 @@ class CameraCtrlsApp(Gtk.Application):
         about = Gtk.AboutDialog(transient_for=self.window, modal=self.window)
         about.set_program_name('Cameractrls')
         about.set_authors(['Gergo Koteles <soyer@irl.hu>'])
-        about.set_copyright('Copyright © 2022 Gergo Koteles')
+        about.set_copyright('Copyright © 2022 - 2023 Gergo Koteles')
         about.set_license_type(Gtk.License.MIT_X11)
+        about.set_logo_icon_name('hu.irl.cameractrls')
         about.set_website(ghurl)
         about.set_website_label('GitHub')
         about.set_version(version)
